@@ -41,15 +41,6 @@
 #include "gnome-print-i18n.h"
 #include "gnome-font-dialog.h"
 
-#if 0
-#include <gdk/gdkkeysyms.h>
-#include <libgnomeprint/gnome-font-dialog.h>
-#include <libgnomeui/gnome-stock.h>
-#include <libgnomeui/gnome-canvas-rect-ellipse.h>
-#include <libgnomeprint/gnome-canvas-hacktext.h>
-#include <libgnomeprint/gnome-font-family.h>
-#endif
-
 struct _GnomeFontSelection
 {
 	GtkHBox hbox;
