@@ -18,7 +18,7 @@
 G_BEGIN_DECLS
 
 #include <gtk/gtkbin.h>
-#include <libgnomeprint/gpa-private.h>
+#include <libgnomeprint/gnome-print-config.h>
 
 #define GPA_TYPE_WIDGET (gpa_widget_get_type ())
 #define GPA_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GPA_TYPE_WIDGET, GPAWidget))
@@ -32,7 +32,7 @@ typedef struct _GPAWidgetClass GPAWidgetClass;
 
 struct _GPAWidget {
 	GtkBin bin;
-	GPANode *node;
+	GnomePrintConfig *config;
 };
 
 struct _GPAWidgetClass {
@@ -42,9 +42,9 @@ struct _GPAWidgetClass {
 
 GtkType gpa_widget_get_type (void);
 
-GtkWidget *gpa_widget_new (GtkType type, GPANode *node);
+GtkWidget *gpa_widget_new (GtkType type, GnomePrintConfig *config);
 
-gboolean gpa_widget_construct (GPAWidget *widget, GPANode *node);
+gboolean gpa_widget_construct (GPAWidget *widget, GnomePrintConfig *config);
 
 G_END_DECLS
 
